powered by
Computes the Kendall's coefficient of concordance.
kendall.w(raw, correct = TRUE)
The resulting list consists of title, kendall.w, chisq, df, pval, report.
title
kendall.w
chisq
df
pval
report
A data frame or matrix contains n subjects * m raters.
Logical. Indicates whether the W should be corrected for ties within raters.
library(DTSEA) library(tibble) # Load the data data <- tribble(~x, ~y, ~z, 1,1,2, 5,6,5, 7,8,4, 2,3,2, 8,6,5) # Run Kendall's W print(kendall.w(data)$report)
Run the code above in your browser using DataLab